==> ayatana-indicator-display_22.2.0.orig.tar.gz: ayatana-indicator-display-22.2.0/README.md <==
# Ayatana System Indicator &mdash; Display [![Build Status](https://api.travis-ci.com/AyatanaIndicators/ayatana-indicator-display.svg)](https://travis-ci.com/github/AyatanaIndicators/ayatana-indicator-display)

## About Ayatana Indicators

The Ayatana Indicators project is the continuation of Application
Indicators and System Indicators, two technologies developed by Canonical
Ltd. for the Unity7 desktop.

Application Indicators are a GTK implementation of the StatusNotifierItem
Specification (SNI) that was originally submitted to freedesktop.org by
KDE.

System Indicators are an extensions to the Application Indicators idea.
System Indicators allow for far more widgets to be displayed in the
indicator's menu.

The Ayatana Indicators project is the new upstream for application
indicators, system indicators and associated projects with a focus on
making Ayatana Indicators a desktop agnostic technology.

On GNU/Linux, Ayatana Indicators are currently available for desktop
envinronments like MATE (used by default in [Ubuntu
MATE](https://ubuntu-mate.com)), XFCE (used by default in
[Xubuntu](https://bluesabre.org/2021/02/25/xubuntu-21-04-progress-update/),
LXDE, and the Budgie Desktop).

The Lomiri Operating Environment (UI of the Ubuntu Touch OS, formerly
known as Unity8) uses Ayatana Indicators for rendering its notification
area and the [UBports](https://ubports.com) project is a core contributor
to the Ayatana Indicators project.

For further info, please visit:
https://ayatana-indicators.org

## The Display Ayatana System Indicator

The -display Ayatana System Indicator is the display menu indicator for
Lomiri (Currently rotation-lock only, but we are planning to add further
functionality for desktops, e.g. MATE, XFCE, LXDE). Its behavior and features will be listed at
https://wiki.ayatana-indicators.org/AyatanaIndicatorDisplay

## License and Copyright

See COPYING and AUTHORS file in this project.

## Building and Testing

For instructions on building and running built-in tests, see the INSTALL.md file.

==> ayatana-indicator-display_24.5.2.orig.tar.gz: ayatana-indicator-display-24.5.2/README.md <==
# Ayatana System Indicator &mdash; Display [![Build Status](https://api.travis-ci.com/AyatanaIndicators/ayatana-indicator-display.svg)](https://travis-ci.com/github/AyatanaIndicators/ayatana-indicator-display)

## About Ayatana Indicators

The Ayatana Indicators project is the continuation of Application
Indicators and System Indicators, two technologies developed by Canonical
Ltd. for the Unity7 desktop.

Application Indicators are a GTK implementation of the StatusNotifierItem
Specification (SNI) that was originally submitted to freedesktop.org by
KDE.

System Indicators are an extensions to the Application Indicators idea.
System Indicators allow for far more widgets to be displayed in the
indicator's menu.

The Ayatana Indicators project is the new upstream for application
indicators, system indicators and associated projects with a focus on
making Ayatana Indicators a desktop agnostic technology.

On GNU/Linux, Ayatana Indicators are currently available for desktop
envinronments like MATE (used by default in [Ubuntu
MATE](https://ubuntu-mate.com)), XFCE (used by default in
[Xubuntu](https://bluesabre.org/2021/02/25/xubuntu-21-04-progress-update/),
LXDE, and the Budgie Desktop).

The Lomiri Operating Environment (UI of the Ubuntu Touch OS, formerly
known as Unity8) uses Ayatana Indicators for rendering its notification
area and the [UBports](https://ubports.com) project is a core contributor
to the Ayatana Indicators project.

For further info, please visit:
https://ayatana-indicators.org

## The Display Ayatana System Indicator

The -display Ayatana System Indicator is the display menu indicator for
MATE and Lomiri (optionally for others, e.g. XFCE, LXDE). Its behavior
and features will be listed at
https://wiki.ayatana-indicators.org/AyatanaIndicatorDisplay

## License and Copyright

See COPYING and AUTHORS file in this project.

## Building and Testing

For instructions on building and running built-in tests, see the INSTALL.md file.
